from setuptools import find_packages, setup

setup(
    author="Marcin Kurczewski",
    author_email="rr-@sakuya.pl",
    name="urwid_readline",
    description=(
        "A textbox edit widget for urwid that supports readline shortcuts"
    ),
    version="0.13",
    url="https://github.com/rr-/urwid_readline",
    packages=find_packages(),
    install_requires=["urwid"],
    classifiers=[
        "Environment :: Console",
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Operating System :: POSIX :: Linux",
        "Programming Language :: Python :: 3 :: Only",
        "Topic :: Desktop Environment",
        "Topic :: Software Development",
        "Topic :: Software Development :: Widget Sets",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
    extras_require={
        "dev": ["black", "pytest"],
    },
)



import urwid

import urwid_readline


def unhandled_input(txt, key):
    if key in ("ctrl q", "ctrl Q"):
        raise urwid.ExitMainLoop()
    txt.set_edit_text("unknown key: " + repr(key))
    txt.set_edit_pos(len(txt.edit_text))


def compl(text, state):
    cmd = ("start", "stop", "next")
    tmp = [c for c in cmd if c and c.startswith(text)] if text else cmd
    try:
        return tmp[state]
    except (IndexError, TypeError):
        return None


def main():
    txt = urwid_readline.ReadlineEdit(multiline=True)
    txt.enable_autocomplete(compl)
    fill = urwid.Filler(txt, "top")
    loop = urwid.MainLoop(
        fill, unhandled_input=lambda key: unhandled_input(txt, key)
    )
    loop.run()


if __name__ == "__main__":
    main()
